# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OperatorMonitorReport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status': 'OperatorStatus',
        'status_info': 'str'
    }

    attribute_map = {
        'name': 'name',
        'status': 'status',
        'status_info': 'status_info'
    }

    def __init__(self, name=None, status=None, status_info=None):  # noqa: E501
        """OperatorMonitorReport - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._status = None
        self._status_info = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if status_info is not None:
            self.status_info = status_info

    @property
    def name(self):
        """Gets the name of this OperatorMonitorReport.  # noqa: E501

        Unique name of the operator.  # noqa: E501

        :return: The name of this OperatorMonitorReport.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OperatorMonitorReport.

        Unique name of the operator.  # noqa: E501

        :param name: The name of this OperatorMonitorReport.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this OperatorMonitorReport.  # noqa: E501


        :return: The status of this OperatorMonitorReport.  # noqa: E501
        :rtype: OperatorStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OperatorMonitorReport.


        :param status: The status of this OperatorMonitorReport.  # noqa: E501
        :type: OperatorStatus
        """

        self._status = status

    @property
    def status_info(self):
        """Gets the status_info of this OperatorMonitorReport.  # noqa: E501

        Detailed information about the operator state.  # noqa: E501

        :return: The status_info of this OperatorMonitorReport.  # noqa: E501
        :rtype: str
        """
        return self._status_info

    @status_info.setter
    def status_info(self, status_info):
        """Sets the status_info of this OperatorMonitorReport.

        Detailed information about the operator state.  # noqa: E501

        :param status_info: The status_info of this OperatorMonitorReport.  # noqa: E501
        :type: str
        """

        self._status_info = status_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OperatorMonitorReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OperatorMonitorReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
